@@ -1,5 +1,5 @@
 #
-# $Id: Base.pm,v 8.2 2004/08/24 14:28:33 wpm Exp $
+# $Id$
 #
 # (c) 2003-2004 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
@@ -13,12 +13,13 @@ use strict;
 use English;
 use Carp;
 use File::Basename qw(basename);
+use Date::Format;
 
 use IO::File;
 use IO::Pipe;
 
 our $AUTOLOAD	= "";
-our $VERSION = '1.7';
+our $VERSION = '1.99';
 
 our %Carp =
   (
@@ -53,12 +54,17 @@ sub new {
 
     my $self = {};
 
-    foreach my $key ( qw( localtime noauth localauth encrypt quiet ) ) {
+    foreach my $key ( qw( localtime noauth localauth encrypt quiet timestamps ) ) {
 	$self->{$key}++ if $args{$key};
     }
 
     # AFS::Command::VOS -> vos
-    $self->{command} = $args{command} || lc((split(/::/,$class))[2]);
+    if ( $args{command} ) {
+        my @commands = (split /\s+/,$args{command});
+        push (@{$self->{command}},@commands);
+    } else {
+        @{$self->{command}} = lc((split(/::/,$class))[2]);
+    }
 
     bless $self, $class;
 
@@ -141,11 +147,11 @@ sub _operations {
 		  $self->_Croak("Unable to redirect stdout: $ERRNO\n");
 
 		if ( $type eq 'default' ) {
-		    exec $self->{command}, 'help';
+		    exec @{$self->{command}}, 'help';
 		} else {
-		    exec $self->{command}, 'offline', '-help';
+		    exec @{$self->{command}}, 'offline', '-help';
 		}
-		die "Unable to exec $self->{command} help: $ERRNO\n";
+		die "Unable to exec @{$self->{command}} help: $ERRNO\n";
 
 	    } else {
 
@@ -173,7 +179,7 @@ sub _operations {
 	    }
 
 	    if ( $? ) {
-		$self->_Carp("Error running $self->{command} help.  Unable to configure $class");
+		$self->_Carp("Error running @{$self->{command}} help.  Unable to configure $class");
 		return;
 	    }
 
@@ -199,10 +205,11 @@ sub _arguments {
        aliases		=> {},
       };
 
-    my $command = $self->{command};
+    my @command;
+    push (@command, @{$self->{command}});
 
     unless ( $self->_operations($operation) ) {
-	$self->_Carp("Unsupported $command operation '$operation'\n");
+	$self->_Carp("Unsupported @command operation '$operation'\n");
 	return;
     }
 
@@ -229,8 +236,8 @@ sub _arguments {
 	  die "Unable to redirect stderr: $ERRNO\n";
 	STDOUT->fdopen( $pipe->writer()->fileno(), "w" ) ||
 	  die "Unable to redirect stdout: $ERRNO\n";
-	exec $command, $operation, '-help';
-	die "Unable to exec $command help $operation: $ERRNO\n";
+	exec @command, $operation, '-help';
+	die "Unable to exec @command help $operation: $ERRNO\n";
 
     } else {
 
@@ -239,12 +246,12 @@ sub _arguments {
 	while ( <$pipe> ) {
 
 	    if ( /Unrecognized operation '$operation'/ ) {
-		$self->_Carp("Unsupported $command operation '$operation'\n");
+		$self->_Carp("Unsupported @command operation '$operation'\n");
 		$errors++;
 		last;
 	    }
 
-	    next unless s/^Usage:.*$command\s+$operation\s+//;
+	    next unless s/^Usage:.*\s+$operation\s+//;
 
 	    while ( $_ ) {
 		if ( s/^\[\s*-(\w+?)\s*\]\s*//  ) {
@@ -261,7 +268,7 @@ sub _arguments {
 		} elsif ( s/^\s*-(\w+?)\s*// ) {
 		    $arguments->{required}->{$1} = 0;
 		} else {
-		    $self->_Carp("Unable to parse $command help for $operation\n" .
+		    $self->_Carp("Unable to parse @command help for $operation\n" .
 				 "Unrecognized string: '$_'");
 		    $errors++;
 		    last;
@@ -298,7 +305,7 @@ sub _arguments {
     }
 
     if ( $? ) {
-	$self->_Carp("Error running $command $operation -help.  Unable to configure $command $operation");
+	$self->_Carp("Error running @command $operation -help.  Unable to configure @command $operation");
 	$errors++;
     }
 
@@ -316,7 +323,7 @@ sub _save_stderr {
 	return;
     };
 
-    my $command = basename($self->{command});
+    my $command = basename((split /\s+/,@{$self->{command}})[0]);
 
     $self->{tmpfile} = "/tmp/.$command.$self->{operation}.$$";
 
@@ -405,7 +412,7 @@ sub _parse_arguments {
 
     } else {
 
-	my @argv = ( $self->{command}, $self->{operation} );
+	my @argv = ( @{$self->{command}}, $self->{operation} );
 
 	foreach my $key ( keys %args ) {
 	    next unless $arguments->{aliases}->{$key};
@@ -553,6 +560,7 @@ sub _parse_output {
     $self->{errors} = "";
 
     while ( defined($_ = $self->{handle}->getline()) ) {
+	$self->{errors} .= time2str("[%Y-%m-%d %H:%M:%S] ",time,'GMT') if $self->{timestamps};
 	$self->{errors} .= $_;
     }
 
