@@ -1,5 +1,5 @@
 #
-# $Id: PTS.pm,v 8.1 2004/05/17 13:04:04 wpm Exp $
+# $Id$
 #
 # (c) 2003-2004 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
@@ -20,7 +20,7 @@ use AFS::Object::Group;
 use AFS::Object::User;
 
 our @ISA = qw(AFS::Command::Base);
-our $VERSION = '1.7';
+our $VERSION = '1.99';
 
 sub creategroup {
 
@@ -341,7 +341,7 @@ sub membership {
     my $group = undef;
 
     while ( defined($_ = $self->{handle}->getline()) ) {
-	
+
 	if ( /(\S+) \(id: (-?\d+)\)/ ) {
 
 	    $result->_addUser($user) if $user;
@@ -373,7 +373,9 @@ sub membership {
 		$group->_addMembership($1);
 	    }
 
-	} elsif ( /unable to get membership/ ) {
+	} elsif ( /unable to get membership/ ||
+		  /User or group doesn't exist/ ||
+		  /membership list for id \d+ exceeds display limit/ ) {
 
 	    #
 	    # pts still (as of OpenAFS 1.2.8) doesn't have proper exit codes.
