@@ -1,5 +1,5 @@
 #
-# $Id: VOS.pm,v 8.2 2004/08/24 14:29:02 wpm Exp $
+# $Id$
 #
 # (c) 2003-2004 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
@@ -23,7 +23,7 @@ use AFS::Object::Partition;
 use AFS::Object::Transaction;
 
 our @ISA = qw(AFS::Command::Base);
-our $VERSION = '1.7';
+our $VERSION = '1.99';
 
 sub examine {
 
@@ -192,6 +192,21 @@ sub examine {
 		    next;
 		}
 
+		if ( /^\s+Copy\s+(.*)\s*$/ ) {
+		    $header->_setAttribute( copyTime	=> $1 );
+		    next;
+		}
+
+		if ( /^\s+Backup\s+(.*)\s*$/ ) {
+		    $header->_setAttribute( backupTime	=> $1 );
+		    next;
+		}
+
+		if ( /^\s+Last Access\s+(.*)\s*$/ ) {
+		    $header->_setAttribute( access	=> $1 );
+		    next;
+		}
+
 		if ( /^\s+Last Update\s+(.*)\s*$/ ) {
 		    $header->_setAttribute( update	=> $1 );
 		    next;
@@ -354,8 +369,6 @@ sub examine {
 
 	    }
 
-	    next;
-
 	}
 
 	#
@@ -793,6 +806,21 @@ sub listvol {
 			next;
 		    }
 
+		if ( /^\s+Copy\s+(.*)\s*$/ ) {
+		    $volume->_setAttribute( copyTime	=> $1 );
+		    next;
+		}
+
+		if ( /^\s+Backup\s+(.*)\s*$/ ) {
+		    $volume->_setAttribute( backupTime	=> $1 );
+		    next;
+		}
+
+		if ( /^\s+Last Access\s+(.*)\s*$/ ) {
+		    $volume->_setAttribute( access	=> $1 );
+		    next;
+		}
+
 		    if ( /^\s+Last Update\s+(.*)\s*$/ ) {
 			$volume->_setAttribute( update => $1 );
 			next;
@@ -976,12 +1004,13 @@ sub dump {
     my $gzip_default = 6;
     my $bzip2_default = 6;
 
+    my $nocompress = delete $args{nocompress} || undef;
     my $gzip = delete $args{gzip} || undef;
     my $bzip2 = delete $args{bzip2} || undef;
     my $filterout = delete $args{filterout} || undef;
 
-    if ( $gzip && $bzip2 ) {
-	$self->_Carp("Invalid argument combination: only one of 'gzip' or 'bzip2' may be specified");
+    if ( $gzip && $bzip2 && $nocompress ) {
+	$self->_Carp("Invalid argument combination: only one of 'gzip' or 'bzip2' or 'nocompress' may be specified");
 	return;
     }
 
@@ -992,9 +1021,9 @@ sub dump {
 
     if ( $file ne 'stdout' ) {
 
-	if ( $file =~ /\.gz$/ && not defined $gzip ) {
+	if ( $file =~ /\.gz$/ && not defined $gzip and not defined $nocompress ) {
 	    $gzip = $gzip_default;
-	} elsif ( $file =~ /\.bz2$/ && not defined $bzip2 ) {
+	} elsif ( $file =~ /\.bz2$/ && not defined $bzip2 and not defined $nocompress ) {
 	    $bzip2 = $bzip2_default;
 	}
 
@@ -1070,12 +1099,13 @@ sub restore {
 	return;
     };
 
+    my $nocompress = delete $args{nocompress} || undef;
     my $gunzip = delete $args{gunzip} || undef;
     my $bunzip2 = delete $args{bunzip2} || undef;
     my $filterin = delete $args{filterin} || undef;;
 
-    if ( $gunzip && $bunzip2 ) {
-	$self->_Carp("Invalid argument combination: only one of 'gunzip' or 'bunzip2' may be specified");
+    if ( $gunzip && $bunzip2 && $nocompress ) {
+	$self->_Carp("Invalid argument combination: only one of 'gunzip' or 'bunzip2' or 'nocompress' may be specified");
 	return;
     }
 
@@ -1086,9 +1116,9 @@ sub restore {
 
     if ( $file ne 'stdin' ) {
 
-	if ( $file =~ /\.gz$/ && not defined $gunzip ) {
+	if ( $file =~ /\.gz$/ && not defined $gunzip and not defined $nocompress ) {
 	    $gunzip = 1;
-	} elsif ( $file =~ /\.bz2$/ && not defined $bunzip2 ) {
+	} elsif ( $file =~ /\.bz2$/ && not defined $bunzip2 and not defined $nocompress ) {
 	    $bunzip2 = 1;
 	}
 
